@@ -3,10 +3,10 @@
  *  Module    : tin.h
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2021-12-13
+ *  Updated   : 2022-09-20
  *  Notes     : #include files, #defines & struct's
  *
- * Copyright (c) 1997-2022 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1997-2023 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -127,7 +127,7 @@ enum rc_state { RC_IGNORE, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
 #	endif /* DECL_ERRNO */
 #endif /* !errno */
 #if !defined(EHOSTUNREACH)
-#   define EHOSTUNREACH 113
+#	define EHOSTUNREACH 113
 #endif /* !EHOSTUNREACH */
 
 #ifdef HAVE_STDDEF_H
@@ -191,6 +191,7 @@ enum rc_state { RC_IGNORE, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
  * TODO: what if !CPP_DOES_CONCAT
  *       add configure check for PRIdLEAST64
  *       add configure check for SCNdLEAST64
+ *       add configure check for INT64_MAX, LLONG_MAX, LONG_MAX
  */
 #	if defined(HAVE_INT_LEAST64_T) && !defined(HAVE_INTTYPES_H)
 #		undef HAVE_INT_LEAST64_T
@@ -213,11 +214,13 @@ enum rc_state { RC_IGNORE, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
 #		define T_ARTNUM_PFMT PRIdLEAST64
 #		define T_ARTNUM_SFMT SCNdLEAST64
 #		define T_ARTNUM_CONST(v) INT64_C(v)
+#		define ARTNUM_MAX INT64_MAX
 #	else
 		typedef long long t_artnum;
 #		define T_ARTNUM_PFMT "lld"
 #		define T_ARTNUM_SFMT "lld"
 #		define T_ARTNUM_CONST(v) v ## LL
+#		define ARTNUM_MAX LLONG_MAX
 #	endif /* HAVE_INT_LEAST64_T && HAVE_INT64_C */
 #	ifdef HAVE_ATOLL
 #		define atoartnum atoll
@@ -230,6 +233,7 @@ enum rc_state { RC_IGNORE, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
 #	define T_ARTNUM_PFMT "ld"
 #	define T_ARTNUM_SFMT "ld"
 #	define T_ARTNUM_CONST(v) v ## L
+#	define ARTNUM_MAX LONG_MAX
 #	define atoartnum atol
 #	define strtoartnum strtol
 #endif /* USE_LONG_ARTICLE_NUMBERS */
@@ -698,15 +702,16 @@ enum rc_state { RC_IGNORE, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
 /*
  * URL related regexs:
  * add TELNET (RFC 4248), WAIS (RFC 4156), IMAP (RFC 2192), NFS (RFC 2224)
- *     LDAP (RFC 2255), POP (RFC 2384)
- * add IPv6 (RFC 2732, RFC 2373) support
+ *     LDAP (RFC 2255), POP (RFC 2384), ...
+ * add IPv6 (RFC 3986) support
  */
 /*
  * case insensitive
  * TODO: - split out ftp (only ftp allows username:passwd@, RFC 1738)?
  *       - test IDNA (RFC 3490) case
+ *       - adjust to follow RFC 3986 (section 2.3)
  */
-#define URL_REGEX	"\\b(?:https?|ftp|gopher)://(?:[^:@/\\s]*(?::[^:@/\\s]*)?@)?(?:(?:(?:[^\\W_](?:(?:-|[^\\W_]){0,61}(?<!---)[^\\W_])?|xn--[^\\W_](?:-(?!-)|[^\\W_]){1,57}[^\\W_])\\.)+[a-z]{2,14}\\.?|localhost|(?:(?:2[0-4]\\d|25[0-5]|[01]?\\d\\d?)\\.){3}(?:2[0-4]\\d|25[0-5]|[01]?\\d\\d?)|\\[(?:(?:[0-9A-F]{0,4}:){1,7}[0-9A-F]{1,4}|(?:[0-9A-F]{0,4}:){1,3}(?:(?:2[0-4]\\d|25[0-5]|[01]?\\d\\d?)\\.){3}(?:2[0-4]\\d|25[0-5]|[01]?\\d\\d?))\\])(?::\\d+)?(?(?=[^\\)\\]\\>\"\\s]*\\()(?:/[^\\]\\>\"\\s]*|$|(?=[)\\]\\>\"\\s]))|(?:/[^)\\]\\>\"\\s]*|$|(?=[)\\]\\>\"\\s])))"
+#define URL_REGEX	"\\b(?:https?|ftp|gopher)://(?:[^:@/\\s]*(?::[^:@/\\s]*)?@)?(?:(?:(?:[^\\W_](?:(?:-|[^\\W_]){0,61}(?<!---)[^\\W_])?|xn--[^\\W_](?:-(?!-)|[^\\W_]){1,57}[^\\W_])\\.)+[a-z]{2,18}\\.?|localhost|(?:(?:2[0-4]\\d|25[0-5]|[01]?\\d\\d?)\\.){3}(?:2[0-4]\\d|25[0-5]|[01]?\\d\\d?)|\\[(?:(?:[0-9A-F]{0,4}:){1,7}[0-9A-F]{1,4}|(?:[0-9A-F]{0,4}:){1,3}(?:(?:2[0-4]\\d|25[0-5]|[01]?\\d\\d?)\\.){3}(?:2[0-4]\\d|25[0-5]|[01]?\\d\\d?))\\])(?::\\d+)?(?:[-a-zA-Z0-9()@:%_\\+.~#?&\\/=\\$,]*)"
 /*
  * case insensitive
  * TOFO: check against RFC 6068
@@ -753,8 +758,37 @@ enum rc_state { RC_IGNORE, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
 #endif /* BOOL_H */
 
 /* Philip Hazel's Perl regular expressions library */
+#ifdef HAVE_LIB_PCRE2
+
+#define PCRE2_CODE_UNIT_WIDTH 0
+#include <pcre2.h>
+
+#define REGEX_CASELESS PCRE2_CASELESS
+#define REGEX_ANCHORED PCRE2_ANCHORED
+#define REGEX_NOTEMPTY PCRE2_NOTEMPTY
+
+#define REGEX_ERROR_NOMATCH PCRE2_ERROR_NOMATCH
+
+#define REGEX_OPTIONS uint32_t
+#define REGEX_NOFFSET uint32_t
+#define REGEX_SIZE size_t
+
+#else /* HAVE_LIB_PCRE2 */
+
 #include <pcre.h>
 
+#define REGEX_CASELESS PCRE_CASELESS
+#define REGEX_ANCHORED PCRE_ANCHORED
+#define REGEX_NOTEMPTY PCRE_NOTEMPTY
+
+#define REGEX_ERROR_NOMATCH PCRE_ERROR_NOMATCH
+
+#define REGEX_OPTIONS int
+#define REGEX_NOFFSET int
+#define REGEX_SIZE int
+
+#endif /* HAVE_LIB_PCRE2 */
+
 #ifdef HAVE_ICONV
 #	define CHARSET_CONVERSION 1
 #	ifdef HAVE_ICONV_H
@@ -816,8 +850,14 @@ enum rc_state { RC_IGNORE, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
 #	define forever	for(;;)
 #endif /* !forever */
 
-/* safe strcpy into fixed-legth buffer */
-#define STRCPY(dst, src)	(dst[sizeof(dst) - 1] = '\0', strncpy(dst, src, sizeof(dst) - 1))
+/*
+ * safe strcpy into fixed-legth buffer
+ */
+#if 1
+#	define STRCPY(dst, src)	(strncpy(dst, src, sizeof(dst) - 1), dst[sizeof(dst) - 1] = '\0')
+#else
+#	define STRCPY(dst, src)	(*(dst) = '\0', strncat(dst, src, sizeof(dst) - 1))
+#endif /* 1 */
 
 #define STRCMPEQ(s1, s2)	(strcmp((s1), (s2)) == 0)
 #define STRNCMPEQ(s1, s2, n)	(strncmp((s1), (s2), n) == 0)
@@ -982,6 +1022,16 @@ enum rc_state { RC_IGNORE, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
 #define SKIP_TRAILING			2
 #define COMPACT_MULTIPLE		4
 
+/*
+ * defines for tinrc.show_help_mail_sign
+ */
+enum {
+	SHOW_SIGN_NONE = 0,
+	SHOW_SIGN_HELP,
+	SHOW_SIGN_MAIL,
+	SHOW_SIGN_BOTH
+};
+
 /*
  * MIME Encodings
  */
@@ -1679,6 +1729,9 @@ struct t_attribute {
 	IntField(thread_perc);			/* percentage threading threshold */
 	IntField(show_author);			/* 0=none, 1=name, 2=addr, 3=both */
 	BoolField(show_signatures);		/* 0=none, 1=show signatures */
+#if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
+	BoolField(suppress_soft_hyphens);	/* set TRUE to remove soft hyphens (U+00AD) from articles */
+#endif /* MULTIBYTE_ABLE && !NO_LOCALE */
 	IntField(trim_article_body);	/* 0=Don't trim article body, 1=Skip leading blank lines,
 						2=Skip trailing blank lines, 3=Skip leading and trailing blank lines,
 						4=Compact multiple blank lines between textblocks,
@@ -1768,6 +1821,9 @@ struct t_attribute_state {
 	BoolField(signature_repost);
 	BoolField(sort_article_type);
 	BoolField(sort_threads_type);
+#if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
+	BoolField(suppress_soft_hyphens);
+#endif /* MULTIBYTE_ABLE && !NO_LOCALE */
 	BoolField(tex2iso_conv);
 	BoolField(thread_articles);
 	BoolField(thread_catchup_on_exit);
@@ -1958,11 +2014,30 @@ struct t_filter_rule {
  * Filter cache structure using Philip Hazel's Perl regular expression
  * library (see pcre/pcre.[ch] for details)
  */
+#ifdef HAVE_LIB_PCRE2
+
+struct regex_cache {
+	pcre2_code_8 *re;
+	pcre2_match_data_8 *match;
+};
+
+#define REGEX_CACHE_INITIALIZER { NULL, NULL }
+
+#else /* HAVE_LIB_PCRE2 */
+
 struct regex_cache {
 	pcre *re;
 	pcre_extra *extra;
+	int *ovector;
+	int ovecalloc;	/* number of allocated integers */
+	int ovecmax;	/* max valid pairs in ovector, i.e. max capturecount */
+	int oveccount;	/* valid capture count from last regex_exec */
 };
 
+#define REGEX_CACHE_INITIALIZER { NULL, NULL, NULL, 0, 0, 0 }
+
+#endif /* HAVE_LIB_PCRE2 */
+
 struct t_save {
 	char *path;
 	char *file;					/* ptr to file part of *path */
@@ -2167,7 +2242,6 @@ typedef void (*t_sortfunc)(void *, size_t, size_t, t_compfunc);
 #define ENV_VAR_SHELL		"SHELL"
 #define TIN_EDITOR_FMT		"%E +%N %F"
 #define MAILER_FORMAT		"%M -oi -t < %F"
-#define TMPDIR	get_val("TMPDIR", _PATH_TMP)
 #ifdef HAVE_KEY_PREFIX
 #	define KEY_PREFIX		0x8f: case 0x9b
 #endif /* HAVE_KEY_PREFIX */
@@ -2485,12 +2559,18 @@ extern struct tm *localtime(time_t *);
 #	endif /* HAVE_STDNORETURN_H */
 #else
 #	undef _Noreturn
+	/*
+	 * gcc says "The attribute noreturn is not implemented in GCC
+	 * versions earlier than 2.5" but gcc 2.7.2.3 on m68k-sony-newsos
+	 * or mips-dec-osf1 still doesn't know __attribute__((noreturn)).
+	 * __GNUC__ > 2 should be fine
+	 */
 #	if defined(__GNUC__) && !defined(__cplusplus) && !defined(__APPLE_CC__) && !defined(__NeXT__)
-#		if __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ > 6)
+#		if __GNUC__ > 2
 #			define _Noreturn __attribute__((noreturn))
 #		else
 #			define _Noreturn /**/
-#		endif /* __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ > 6) */
+#		endif /* __GNUC__ > 2 */
 #	else
 #		define _Noreturn /**/
 #	endif /* __GNUC__ && !__cplusplus && !__APPLE_CC__ && !__NeXT__ */
