@@ -3,7 +3,7 @@
  *  Module    : auth.c
  *  Author    : Dirk Nimmich <nimmich@muenster.de>
  *  Created   : 1997-04-05
- *  Updated   : 2018-06-04
+ *  Updated   : 2022-06-16
  *  Notes     : Routines to authenticate to a news server via NNTP.
  *              DON'T USE get_respcode() THROUGHOUT THIS CODE.
  *
@@ -409,8 +409,13 @@ authinfo_plain(
 			 * READER?
 			 */
 #	ifdef DEBUG
-			if ((debug & DEBUG_NNTP) && verbose > 1)
-				debug_print_file("NNTP", "authorization not allowed in current state");
+			if ((debug & DEBUG_NNTP) && verbose > 1) {
+				debug_print_file("NNTP", "authorization not allowed in current state:");
+				debug_print_file("NNTP", "\tCAPABILITIES: %s", nntp_caps.type ? (nntp_caps.type < 2 ? "CAPABILITIES" : "BROKEN" ) : "NONE");
+				debug_print_file("NNTP", "\t%cREADER, %cMODE READER", nntp_caps.reader ? '+' : '-', nntp_caps.mode_reader ? '+' : '-');
+				debug_print_file("NNTP", "\t%cSTARTTLS", nntp_caps.starttls ? '+' : '-');
+				debug_print_file("NNTP", "\t%cAUTHINFO %s%s", nntp_caps.authinfo_state ? '+' : '-', nntp_caps.authinfo_user ? "USER " : "" , nntp_caps.authinfo_sasl ? "SASL" : "");
+			}
 #	endif /* DEBUG */
 			/*
 			 * we return OK_AUTH here once so tin doesn't exit just because a
@@ -509,11 +514,10 @@ do_authinfo_sasl_plain(
 				if (!buffer_to_network(utf8user, c)) {
 					free(utf8user);
 					utf8user = my_strdup(authuser);
-				} else {
-					if (!buffer_to_network(utf8pass, c)) {
-						free(utf8pass);
-						utf8pass = my_strdup(authpass);
-					}
+				}
+				if (!buffer_to_network(utf8pass, c)) {
+					free(utf8pass);
+					utf8pass = my_strdup(authpass);
 				}
 			}
 		}
