@@ -3,10 +3,10 @@
  *  Module    : group.c
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2021-07-25
+ *  Updated   : 2022-10-27
  *  Notes     :
  *
- * Copyright (c) 1991-2021 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1991-2023 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -459,6 +459,11 @@ group_page(
 				show_group_page();
 				break;
 
+			case GLOBAL_CONNECTION_INFO:
+				show_connection_page(GROUP_LEVEL, _(txt_connection_info));
+				show_group_page();
+				break;
+
 			case GLOBAL_TOGGLE_HELP_DISPLAY:		/* toggle mini help menu */
 				toggle_mini_help(GROUP_LEVEL);
 				show_group_page();
@@ -861,7 +866,7 @@ group_page(
 				if (grpmenu.curr >= 0) {
 					char pat[128];
 					char *prompt;
-					struct regex_cache cache = { NULL, NULL };
+					struct regex_cache cache = REGEX_CACHE_INITIALIZER;
 
 					prompt = fmt_string(_(txt_select_pattern), tinrc.default_select_pattern);
 					if (!(prompt_string_default(prompt, tinrc.default_select_pattern, _(txt_info_no_previous_expression), HIST_SELECT_PATTERN))) {
@@ -878,7 +883,7 @@ group_page(
 					} else
 						snprintf(pat, sizeof(pat), REGEX_FMT, tinrc.default_select_pattern);
 
-					if (tinrc.wildcard && !(compile_regex(pat, &cache, PCRE_CASELESS)))
+					if (tinrc.wildcard && !(compile_regex(pat, &cache, REGEX_CASELESS)))
 						break;
 
 					flag = FALSE;
@@ -896,8 +901,7 @@ group_page(
 						update_group_page();
 					}
 					if (tinrc.wildcard) {
-						FreeIfNeeded(cache.re);
-						FreeIfNeeded(cache.extra);
+						regex_cache_destroy(&cache);
 					}
 				}
 				break;
@@ -1468,8 +1472,12 @@ static void
 show_group_title(
 	t_bool clear_title)
 {
-	char buf[LEN], tmp[LEN], flag;
-	int i, art_cnt = 0, recent_art_cnt = 0, selected_art_cnt = 0, read_selected_art_cnt = 0, killed_art_cnt = 0;
+	char buf[LEN], tmp[LEN], keyhelp[MAXKEYLEN], flag;
+	char *grpname;
+	int i, len, keyhelplen, art_cnt = 0, recent_art_cnt = 0, selected_art_cnt = 0, read_selected_art_cnt = 0, killed_art_cnt = 0;
+#if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
+	wchar_t *wtmp, *wtmp2;
+#endif /* MULTIBYTE_ABLE && !NO_LOCALE */
 
 	for_each_art(i) {
 		if (arts[i].thread == ART_EXPIRED)
@@ -1502,10 +1510,9 @@ show_group_title(
 	/*
 	 * build the group title
 	 */
-	/* group name and thread count */
-	snprintf(buf, sizeof(buf), "%s (%d%c",
-		curr_group->name, grpmenu.max,
-		*txt_threading[curr_group->attribute->thread_articles]);
+	/* thread count */
+	snprintf(buf, sizeof(buf), " (%d%c",
+		grpmenu.max, *txt_threading[curr_group->attribute->thread_articles]);
 
 	/* article count */
 	if ((cmdline.args & CMDLINE_GETART_LIMIT) ? cmdline.getart_limit : tinrc.getart_limit)
@@ -1554,11 +1561,57 @@ show_group_title(
 	if (sizeof(buf) > strlen(buf) + strlen(tmp))
 		strcat(buf, tmp);
 
+	/*
+	 * determine max len for centered group name
+	 */
+	if (tinrc.show_help_mail_sign != SHOW_SIGN_NONE) {
+		if (tinrc.show_help_mail_sign == SHOW_SIGN_MAIL)
+			len = cCOLS - (2 * strwidth(_(txt_you_have_mail))) - 2;
+		else {
+			PrintFuncKey(keyhelp, GLOBAL_HELP, group_keys);
+			keyhelplen = strwidth(keyhelp);
+			if (tinrc.show_help_mail_sign == SHOW_SIGN_HELP)
+				len = cCOLS - (2 * (strwidth(_(txt_type_h_for_help)) - 2 + keyhelplen)) - 2;
+			else
+				len = cCOLS - (2 * MAX(strwidth(_(txt_type_h_for_help)) - 2 + keyhelplen, strwidth(_(txt_you_have_mail)))) - 2;
+		}
+	} else
+		len = cCOLS - strwidth(buf) - 2;
+
+	/* group name */
+#if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
+	if ((wtmp = char2wchar_t(curr_group->name)) != NULL) {
+		if (tinrc.abbreviate_groupname)
+			wtmp2 = abbr_wcsgroupname(wtmp, len);
+		else
+			wtmp2 = wstrunc(wtmp, len);
+		grpname = wchar_t2char(wtmp2);
+		free(wtmp);
+		free(wtmp2);
+		if (grpname) {
+			STRCPY(tmp, grpname);
+			strcat(tmp, buf);
+			free(grpname);
+		} else {
+			STRCPY(tmp, buf);
+		}
+	} else
+		STRCPY(tmp, buf);
+#else
+	if (tinrc.abbreviate_groupname)
+		grpname = abbr_groupname(curr_group->name, len);
+	else
+		grpname = strunc(curr_group->name, len);
+	STRCPY(tmp, grpname);
+	strcat(tmp, buf);
+	free(grpname);
+#endif /* MULTIBYTE_ABLE && !NO_LOCALE */
+
 	if (clear_title) {
 		MoveCursor(0, 0);
 		CleartoEOLN();
 	}
-	show_title(buf);
+	show_title(tmp);
 }
 
 
