@@ -3,10 +3,10 @@
  *  Module    : page.c
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2021-09-21
+ *  Updated   : 2022-10-27
  *  Notes     :
  *
- * Copyright (c) 1991-2022 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1991-2023 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -818,6 +818,12 @@ page_goto_next_unread:
 				draw_page(group->name, 0);
 				break;
 
+			case GLOBAL_CONNECTION_INFO:
+				XFACE_CLEAR();
+				show_connection_page(PAGE_LEVEL, _(txt_connection_info));
+				draw_page(group->name, 0);
+				break;
+
 			case GLOBAL_TOGGLE_HELP_DISPLAY:	/* toggle mini help menu */
 				toggle_mini_help(PAGE_LEVEL);
 				draw_page(group->name, 0);
@@ -923,13 +929,6 @@ return_to_index:
 				break;
 
 			case PAGE_GROUP_SELECT:	/* return to group selection page */
-#if 0
-				/* Hasn't been used since tin 1.1 PL4 */
-				if (filter_state == FILTERING) {
-					filter_articles(group);
-					make_threads(group, FALSE);
-				}
-#endif /* 0 */
 				XFACE_CLEAR();
 				return GRP_RETSELECT;
 
@@ -1352,17 +1351,15 @@ draw_page_header(
 		buf[line_len - 1] = '\0';
 	}
 
-#if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
-
 #	ifdef HAVE_COLOR
 	fcol(tinrc.col_head);
 #	endif /* HAVE_COLOR */
 
-	/*
-	 * first line
-	 */
+	/* first line */
 	cur_pos = 0;
 
+#if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
+
 	/* convert to wide-char format string */
 	fmt_thread = char2wchar_t(_(txt_thread_x_of_n));
 
@@ -1515,7 +1512,7 @@ draw_page_header(
 	buf[line_len - 1] = '\0';
 	if ((wtmp = char2wchar_t(buf)) != NULL) {
 		wbuf = wexpand_tab(wtmp, tabwidth);
-		wtmp2 = wstrunc(wbuf, cCOLS - 2 * right_len - 3);
+		wtmp2 = wstrunc(wbuf, cCOLS - 2 * right_len - 4);
 		center_pos = (cCOLS - wcswidth(wtmp2, wcslen(wtmp2))) / 2;
 
 		/* pad out to left */
@@ -1620,20 +1617,8 @@ draw_page_header(
 		}
 	}
 
-	my_fputs(cCRLF, stdout);
-	my_fputs(cCRLF, stdout);
-
 #else /* !MULTIBYTE_ABLE || NO_LOCALE */
 
-#	ifdef HAVE_COLOR
-	fcol(tinrc.col_head);
-#	endif /* HAVE_COLOR */
-
-	/*
-	 * first line
-	 */
-	cur_pos = 0;
-
 	/*
 	 * determine the needed space for the text at the right hand margin
 	 * the formatting info (%4s) needs 3 positions but we need 4 positions
@@ -1816,9 +1801,11 @@ draw_page_header(
 		free(tmp2);
 	}
 
-	my_fputs(cCRLF, stdout);
-	my_fputs(cCRLF, stdout);
 #endif /* MULTIBYTE_ABLE && !NO_LOCALE */
+
+	my_fputs(cCRLF, stdout);
+	my_fputs(cCRLF, stdout);
+
 	free(buf);
 
 #ifdef HAVE_COLOR
@@ -2174,7 +2161,7 @@ void
 info_pager(
 	FILE *info_fh,
 	const char *title,
-	t_bool wrap_at_ends)	/* currently always TRUE */
+	t_bool wrap_at_ends)
 {
 	int offset;
 	t_function func;
@@ -2656,8 +2643,7 @@ build_url_list(
 {
 	char *ptr;
 	int i, count = 0;
-	int offsets[6];
-	int offsets_size = ARRAY_SIZE(offsets);
+	REGEX_SIZE *offsets = NULL;
 	t_url *lptr = NULL;
 
 	for (i = 0; i < artlines; ++i) {
@@ -2677,10 +2663,15 @@ build_url_list(
 		 */
 		forever {
 			/* any matches left? */
-			if (pcre_exec(url_regex.re, url_regex.extra, ptr, (int) strlen(ptr), 0, 0, offsets, offsets_size) == PCRE_ERROR_NOMATCH)
-				if (pcre_exec(mail_regex.re, mail_regex.extra, ptr, (int) strlen(ptr), 0, 0, offsets, offsets_size) == PCRE_ERROR_NOMATCH)
-					if (pcre_exec(news_regex.re, news_regex.extra, ptr, (int) strlen(ptr), 0, 0, offsets, offsets_size) == PCRE_ERROR_NOMATCH)
-						break;
+			if (match_regex_ex(ptr, (int) strlen(ptr), 0, 0, &url_regex) >= 0) {
+				offsets = regex_get_ovector_pointer(&url_regex);
+			} else if (match_regex_ex(ptr, (int) strlen(ptr), 0, 0, &mail_regex) >= 0) {
+				offsets = regex_get_ovector_pointer(&mail_regex);
+			} else if (match_regex_ex(ptr, (int) strlen(ptr), 0, 0, &news_regex) >= 0) {
+				offsets = regex_get_ovector_pointer(&news_regex);
+			} else {
+				break;
+			}
 
 			*(ptr + offsets[1]) = '\0';
 
