@@ -6,7 +6,7 @@
  *  Updated   : 2021-02-23
  *  Notes     : mailcap parsing as defined in RFC 1524
  *
- * Copyright (c) 2000-2022 Urs Janssen <urs@tin.org>, Jason Faultless <jason@altarstone.com>
+ * Copyright (c) 2000-2023 Urs Janssen <urs@tin.org>, Jason Faultless <jason@altarstone.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -135,7 +135,7 @@ get_mailcap_entry(
 							}
 						} /* else no match, no action required */
 					} /* else invalid mailcap line (no /), no action required */
-					if (strlen(wildcap)) {	/* we just had a wildmat match */
+					if (*wildcap) {	/* we just had a wildmat match */
 						fclose(fp);
 						free(mailcaps);
 						return foo;
