@@ -6,7 +6,7 @@
  *  Updated   : 2021-03-04
  *  Notes     : MIME header encoding/decoding stuff
  *
- * Copyright (c) 1995-2021 Chris Blum <chris@resolution.de>
+ * Copyright (c) 1995-2023 Chris Blum <chris@resolution.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -426,7 +426,7 @@ do_b_encode(
 /* if (len8 & (unsigned long) 1 && !isbetween(*w,isstruct_head)) */
 	if (len8 != len8 / 2 * 2 && !isbetween(*w, isstruct_head) && (*w))
 		t--;
-#endif /* MULTIBYTE_ABLE && !NOLOCALE */
+#endif /* MULTIBYTE_ABLE && !NO_LOCALE */
 
 	*t = '\0';
 
@@ -869,7 +869,7 @@ rfc1522_encode(
 #else
 	/*
 	 * Even if MIME_BREAK_LONG_LINES is NOT defined, long headers in mail
-	 * messages should be broken up in accordance with RFC 2047(1522)
+	 * messages should be broken up in accordance with RFC 2047 (1522)
 	 */
 	t_bool break_long_line = ismail;
 #endif /* MIME_BREAK_LONG_LINES */
