@@ -3,10 +3,10 @@
  *  Module    : save.c
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2021-02-25
+ *  Updated   : 2022-08-29
  *  Notes     :
  *
- * Copyright (c) 1991-2021 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1991-2022 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -160,7 +160,7 @@ check_start_save_any_news(
 			break;
 
 		case MAIL_ANY_NEWS:
-			joinpath(savefile, sizeof(savefile), TMPDIR, "tin");
+			joinpath(savefile, sizeof(savefile), tmpdir, "tin");
 #ifdef APPEND_PID
 			snprintf(savefile + strlen(savefile), sizeof(savefile) - strlen(savefile), ".%ld", (long) process_id);
 #endif /* APPEND_PID */
@@ -1155,7 +1155,7 @@ post_process_sh(
 
 		while (fgets(buf, (int) sizeof(buf), fp_in) != NULL) {
 			/* find #!/bin/sh style patterns */
-			if ((fp_out == NULL) && pcre_exec(shar_regex.re, shar_regex.extra, buf, (int) strlen(buf), 0, 0, NULL, 0) >= 0)
+			if ((fp_out == NULL) && match_regex_ex(buf, (int) strlen(buf), 0, 0, &shar_regex) >= 0)
 				fp_out = fopen(file_out, "w");
 
 			/* write to temp file */
@@ -1377,11 +1377,10 @@ match_content_type(
 
 	/* Check for negation */
 	if (*type == '!') {
-		negate = TRUE;
-		++type;
-
-		if (!*type)				/* Invalid type */
+		if (!*(++type))				/* Invalid type */
 			return NO;
+
+		negate = TRUE;
 	}
 
 	/* Split type and subtype */
@@ -1797,7 +1796,7 @@ build_attachment_line(
 #if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
 	char *tmpname;
 	char *tmpbuf;
-#endif /* MULTIBYTE_ABLE && !NOLOCALE */
+#endif /* MULTIBYTE_ABLE && !NO_LOCALE */
 	char buf[BUFSIZ];
 	char buf2[BUFSIZ];
 	char *tree = NULL;
@@ -1852,7 +1851,7 @@ build_attachment_line(
 	FreeIfNeeded(tmpbuf);
 #else
 	snprintf(sptr, cCOLS, "  %s %s%-*.*s%*.*s%s", tin_ltoa(i + 1, 4), buf2, namelen, namelen, name, info_len, info_len, buf, cCRLF);
-#endif /* MULTIBYTE_ABLE && !NOLOCALE */
+#endif /* MULTIBYTE_ABLE && !NO_LOCALE */
 
 	WriteLine(INDEX2LNUM(i), sptr);
 
@@ -1983,7 +1982,7 @@ tag_pattern(
 	char *prompt;
 	const char *name;
 	const char *charset;
-	struct regex_cache cache = { NULL, NULL };
+	struct regex_cache cache = REGEX_CACHE_INITIALIZER;
 	t_part *part;
 	t_partl *lptr;
 
@@ -2007,7 +2006,7 @@ tag_pattern(
 	} else
 		snprintf(pat, sizeof(pat), REGEX_FMT, tinrc.default_select_pattern);
 
-	if (tinrc.wildcard && !(compile_regex(pat, &cache, PCRE_CASELESS)))
+	if (tinrc.wildcard && !(compile_regex(pat, &cache, REGEX_CASELESS)))
 		return;
 
 	lptr = find_part(0);
@@ -2030,8 +2029,7 @@ tag_pattern(
 	}
 
 	if (tinrc.wildcard) {
-		FreeIfNeeded(cache.re);
-		FreeIfNeeded(cache.extra);
+		regex_cache_destroy(&cache);
 	}
 }
 
