@@ -3,10 +3,10 @@
  *  Module    : screen.c
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2021-09-28
+ *  Updated   : 2022-11-01
  *  Notes     :
  *
- * Copyright (c) 1991-2021 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1991-2023 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -44,13 +44,19 @@
 #ifndef TCURSES_H
 #	include "tcurses.h"
 #endif /* !TCURSES_H */
+#ifndef TNNTP_H
+#	include "tnntp.h"
+#endif /* !TNNTP_H */
 
 int mark_offset = 0;
 
+static FILE* msglog = NULL;
+
 #ifndef USE_CURSES
 	struct t_screen *screen;
 #endif /* !USE_CURSES */
 
+static void log_formatted_msg(const char* tag, const char *msg);
 
 /*
  * Move the cursor to the lower-left of the screen, where it won't be annoying
@@ -162,6 +168,7 @@ wait_message(
 		my_fputs(msg, stdout);
 		free(msg);
 	}
+	log_formatted_msg(NULL, buf);
 	free(buf);
 
 #ifdef HAVE_COLOR
@@ -237,6 +244,7 @@ error_message(
 	buf = fmt_message(fmt, ap);
 	my_fputs(buf, stderr);	/* don't use my_fprintf() here due to %format chars */
 	my_fflush(stderr);
+	log_formatted_msg("ERR", buf);
 	free(buf);
 
 	if (cmd_line) {
@@ -448,7 +456,7 @@ erase_arrow(
 			my_fputc(s[mark_offset], stdout);
 			EndInverse();
 		}
-#endif /* MULTIBYTE_ABLE && !NOLOCALE */
+#endif /* MULTIBYTE_ABLE && !NO_LOCALE */
 	}
 }
 
@@ -457,20 +465,64 @@ void
 show_title(
 	const char *title)
 {
+	char keyhelp[MAXKEYLEN];
+	char *helps;
+	const char *sign;
 	int col;
 
-	col = cCOLS - strwidth(_(txt_type_h_for_help));
-	if (col > 0) {
-		MoveCursor(0, col);
+	if (tinrc.show_help_mail_sign != SHOW_SIGN_NONE) {
+		col = MAXKEYLEN + strlen(_(txt_type_h_for_help)) + 1;
+		helps = my_malloc(col);
+
+		switch (signal_context) {
+			case cSelect:
+				PrintFuncKey(keyhelp, GLOBAL_HELP, select_keys);
+				break;
+
+			case cGroup:
+				PrintFuncKey(keyhelp, GLOBAL_HELP, group_keys);
+				break;
+
+			case cThread:
+				PrintFuncKey(keyhelp, GLOBAL_HELP, thread_keys);
+				break;
+
+			default:
+				keyhelp[0] = 'h';
+				keyhelp[1] = '\0';
+		}
+		snprintf(helps, col, _(txt_type_h_for_help), keyhelp);
+
+		switch (tinrc.show_help_mail_sign) {
+			case SHOW_SIGN_MAIL:
+				sign = mail_check(mailbox) ? _(txt_you_have_mail) : NULL;
+				break;
+
+			case SHOW_SIGN_BOTH:
+				sign = mail_check(mailbox) ? _(txt_you_have_mail) : helps;
+				break;
+
+			default:
+				sign = helps;
+				break;
+		}
+
+		if (sign) {
+			col = cCOLS - strwidth(sign);
+			if (col > 0) {
+				MoveCursor(0, col);
 #ifdef HAVE_COLOR
-		fcol(tinrc.col_title);
+				fcol(tinrc.col_title);
 #endif /* HAVE_COLOR */
-		/* you have mail message in */
-		my_fputs((mail_check(mailbox) ? _(txt_you_have_mail) : _(txt_type_h_for_help)), stdout);
+				/* you have mail message in */
+				my_fputs(sign, stdout);
 
 #ifdef HAVE_COLOR
-		fcol(tinrc.col_normal);
+				fcol(tinrc.col_normal);
 #endif /* HAVE_COLOR */
+			}
+		}
+		free(helps);
 	}
 	center_line(0, TRUE, title); /* wastes some space on the left */
 }
@@ -687,3 +739,67 @@ show_progress(
 	last_total = total;
 	last_ratio = ratio;
 }
+
+
+void
+open_msglog(
+	void)
+{
+	char logfile[PATH_LEN];
+	char serverdir[PATH_LEN];
+
+	if (msglog != NULL)
+		return;
+
+#ifdef NNTP_ABLE
+	if (read_news_via_nntp && !read_saved_news && nntp_tcp_port != IPPORT_NNTP)
+		snprintf(logfile, sizeof(logfile), "%s:%u", nntp_server, nntp_tcp_port);
+	else
+#endif /* NNTP_ABLE */
+	{
+		snprintf(logfile, sizeof(logfile), "%s", nntp_server);
+	}
+	joinpath(serverdir, sizeof(serverdir), rcdir, logfile);
+	joinpath(logfile, sizeof(logfile), serverdir, "msglog");
+
+	if ((msglog = fopen(logfile, "w")) != NULL) {
+#ifdef HAVE_FCHMOD
+		fchmod(fileno(msglog), (mode_t) (S_IRUSR|S_IWUSR));
+#else
+#	ifdef HAVE_CHMOD
+		chmod(logfile, (mode_t) (S_IRUSR|S_IWUSR));
+#	endif /* HAVE_CHMOD */
+#endif /* HAVE_FCHMOD */
+	}
+}
+
+
+void
+close_msglog(
+	void)
+{
+	if (msglog)
+		fclose(msglog);
+	msglog = NULL;
+}
+
+
+void
+log_formatted_msg(
+	const char *tag,
+	const char *msg)
+{
+
+	if (msglog == NULL || msg == NULL || strlen(msg) == 0)
+		return;
+
+	if (tag)
+		fprintf(msglog, "%s: %s", tag, msg);
+	else
+		fprintf(msglog, "%s", msg);
+
+	if (msg[strlen(msg) - 1] != '\n')
+		fputc('\n', msglog);
+
+	fflush(msglog);
+}
