@@ -3,10 +3,10 @@
  *  Module    : select.c
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2021-08-28
+ *  Updated   : 2022-10-13
  *  Notes     :
  *
- * Copyright (c) 1991-2021 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1991-2022 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -63,7 +63,7 @@ static void catchup_group(struct t_group *group, t_bool goto_next_unread_group);
 static void draw_group_arrow(void);
 static void read_groups(void);
 static void select_done(void);
-static void select_quit(void);
+_Noreturn static void select_quit(void);
 static void select_read_group(void);
 static void sort_active_file(void);
 static void subscribe_pattern(const char *prompt, const char *message, const char *result, t_bool state);
@@ -142,7 +142,7 @@ selection_page(
 				show_selection_page();
 		} else {
 			if (!yanked_out)
-				yanked_out = bool_not(yanked_out); /* yank out if yanked in */
+				yanked_out = TRUE; /* yank out if yanked in */
 		}
 
 		set_xclick_on();
@@ -595,9 +595,11 @@ void
 show_selection_page(
 	void)
 {
-	char buf[LEN];
-	int i;
+	char buf[LEN], keyhelp[MAXKEYLEN];
+	char *title;
+	int i, keyhelplen;
 	size_t len;
+	const char *secflag = "";
 
 	signal_context = cSelect;
 	currmenu = &selmenu;
@@ -607,8 +609,15 @@ show_selection_page(
 	mark_offset = 0;
 	ucnt_offset = 0;
 
+	if (use_nntps) {
+		if (insecure_nntps)
+			secflag=_("[k]");
+		else
+			secflag=_("[T]");
+	}
+
 	if (read_news_via_nntp)
-		snprintf(buf, sizeof(buf), "%s (%s  %d%s)", _(txt_group_selection), nntp_server, selmenu.max, (tinrc.show_only_unread_groups ? _(" R") : ""));
+		snprintf(buf, sizeof(buf), "%s (%s%s  %d%s)", _(txt_group_selection), nntp_server, secflag, selmenu.max, (tinrc.show_only_unread_groups ? _(" R") : ""));
 	else
 		snprintf(buf, sizeof(buf), "%s (%d%s)", _(txt_group_selection), selmenu.max, (tinrc.show_only_unread_groups ? _(" R") : ""));
 
@@ -617,7 +626,27 @@ show_selection_page(
 
 	ClearScreen();
 	set_first_screen_item();
-	show_title(buf);
+
+	/*
+	 * determine max. length for centered title
+	 */
+	if (tinrc.show_help_mail_sign != SHOW_SIGN_NONE) {
+		if (tinrc.show_help_mail_sign == SHOW_SIGN_MAIL)
+			len = cCOLS - (2 * strwidth(_(txt_you_have_mail))) - 2;
+		else {
+			PrintFuncKey(keyhelp, GLOBAL_HELP, select_keys);
+			keyhelplen = strwidth(keyhelp);
+			if (tinrc.show_help_mail_sign == SHOW_SIGN_HELP)
+				len = cCOLS - (2 * (strwidth(_(txt_type_h_for_help)) - 2 + keyhelplen)) - 2;
+			else
+				len = cCOLS - (2 * MAX(strwidth(_(txt_type_h_for_help)) - 2 + keyhelplen, strwidth(_(txt_you_have_mail)))) - 2;
+		}
+	} else
+		len = cCOLS - 2;
+
+	title = strunc(buf, len);
+	show_title(title);
+	free(title);
 
 	if (sel_fmt.len_grpname_max && !sel_fmt.len_grpname) {
 		/*
@@ -1106,7 +1135,7 @@ reposition_group(
 	if (!prompt_string(buf, pos, HIST_MOVE_GROUP))
 		return default_num;
 
-	if (strlen(pos))
+	if (*pos)
 		pos_num = ((pos[0] == '$') ? selmenu.max : atoi(pos));
 	else {
 		if (tinrc.default_move_group)
@@ -1414,7 +1443,7 @@ subscribe_pattern(
 /*
  * Does NOT return
  */
-static void
+_Noreturn static void
 select_quit(
 	void)
 {
